@@ -177,7 +177,6 @@ there_is_another_patch()
 	if (force || batch) {
 	    say1("No file to patch.  Skipping...\n");
 	    filearg[0] = savestr(bestguess);
-	    skip_rest_of_patch = TRUE;		/* Peter Chang */
 	    return TRUE;
 	}
 	ask1("File to patch: ");
@@ -226,8 +225,6 @@ intuit_diff_type()
     char *newname = Nullch;
     Reg11 int retval;
     bool no_filearg = (filearg[0] == Nullch);
-    bool olddir_exists;
-    bool newdir_exists;
 
     ok_to_create_file = FALSE;
     Fseek(pfp, p_base, 0);
@@ -296,9 +293,8 @@ intuit_diff_type()
 	    goto scan_exit;
 	}
 	if ((!diff_type || diff_type == UNI_DIFF) && strnEQ(s, "@@ -", 4)) {
-	    if ((!reverse && !atol(s+4))
-	        || (reverse && strtailEQ(s, " +0,0 @@\n")))
-	        ok_to_create_file = TRUE;
+	    if (!atol(s+3))
+		ok_to_create_file = TRUE;
 	    p_indent = indent;
 	    p_start = this_line;
 	    p_sline = p_input_line;
@@ -308,7 +304,6 @@ intuit_diff_type()
 	stars_this_line = strnEQ(s, "********", 8);
 	if ((!diff_type || diff_type == CONTEXT_DIFF) && stars_last_line &&
 		 strnEQ(s, "*** ", 4)) {
-	    /* this is the right test only for forward diffs */
 	    if (!atol(s+4))
 		ok_to_create_file = TRUE;
 	    /* if this is a new context diff the character just before */
@@ -340,25 +335,10 @@ intuit_diff_type()
 	if (newtmp != Nullch)
 	    newname = fetchname(newtmp, strippath, ok_to_create_file);
 	if (oldname && newname) {
-	    /* This will generally happen when a new file is to be
-	       created. In this case, prefer an already existing dir. */
-	    if (ok_to_create_file) {
-	        olddir_exists = hasdir(oldname);
-		newdir_exists = hasdir(newname);
-		if (olddir_exists && !newdir_exists)
-		    filearg[0] = savestr(oldname);
-		else if (newdir_exists && !olddir_exists)
-		    filearg[0] = savestr(newname);
-		else if (strlen(oldname) < strlen(newname))
-		    filearg[0] = savestr(oldname);
-		else
-		    filearg[0] = savestr(newname);
-	    } else {
-		if (strlen(oldname) < strlen(newname))
-		    filearg[0] = savestr(oldname);
-		else
-		    filearg[0] = savestr(newname);
-	    }
+	    if (strlen(oldname) < strlen(newname))
+		filearg[0] = savestr(oldname);
+	    else
+		filearg[0] = savestr(newname);
 	}
 	else if (oldname)
 	    filearg[0] = savestr(oldname);
